@@ -15,7 +15,8 @@ def ml(logger=None, file_path=None, log_level=None):
     ml = logging.getLogger(logger)
     ml.setLevel(log_level)
     handler = logging.FileHandler(file_path)
-    formatter = logging.Formatter("%(levelname)s %(asctime)s %(funcName)s %(lineno)d %(message)s")
+    format = "%(created)s %(module)s %(funcName)s %(lineno)d %(message)s"
+    formatter = logging.Formatter(format)
     handler.setFormatter(formatter)
     ml.addHandler(handler)
 
